@@ -13,11 +13,11 @@ File::PCAP::ACAP2PCAP - convert ASA capture to PCAP
 
 =head1 VERSION
 
-Version v0.0.7
+Version v0.0.8
 
 =cut
 
-use version; our $VERSION = qv('v0.0.7');
+use version; our $VERSION = qv('v0.0.8');
 
 =head1 SYNOPSIS
 
@@ -54,8 +54,6 @@ sub new {
 	my $type = ref($self) || $self;
 	
 	my $now   = time;
-	my @today = localtime($now);
-	$today[0] = $today[1] = $today[2] = 0;
 
 	my $fpwargs = {};
 	if (exists $args->{dlt}) {
@@ -72,7 +70,7 @@ sub new {
 	
 	$self = bless {
 		state        => 'unknown',
-		sot          => timegm(@today), # start of today
+		sot          => _get_startday($now,$args), # start of today
         last_sec     => 0,
 		now          => $now,
 		fpw          => $fpw,
@@ -119,6 +117,23 @@ my $r_mdsc = qr/^\s+(\S.*)$/;
 my $r_stop = qr/^([0-9]+) packets? shown$/;
 my $r_dump = qr/^(0x[0-9a-f]+)\s+([0-9a-f][0-9a-f ]{38})\s{8}(.+)$/;
 
+# The function _get_startday() determines the date that the first read
+# captured package should be in. It defaults to the current day.
+#
+sub _get_startday {
+    my ($now,$args) = @_;
+	my @today = localtime($now);
+	$today[0] = $today[1] = $today[2] = 0;
+    if (my $startday = $args->{startday}) {
+        if ($startday =~ /^(\d{4})-?(\d{2})-?(\d{2})$/) {
+            $today[5] = $1 - 1900;
+            $today[4] = $2 -1;
+            $today[3] = $3;
+        }
+    }
+    return timelocal(@today);
+} # _get_startday()
+
 # The function _read_line() reads the input one line at a time and
 # decides what to do with that line.
 #
